@@ -4,9 +4,10 @@ use 5.008;
 use strict;
 use warnings;
 
+use PerlIO::eol;
 use XSLoader;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 XSLoader::load __PACKAGE__, $VERSION;
 
@@ -22,18 +23,18 @@ PerlIO::nline - Perl extension for newline translation
 
 =head1 DESCRIPTION
 
-This layer translates any of \r, \n or \r\n into \n on input, and into
-\r\n on output. It is probably a bad idea to mix it with :crlf on one 
-filehandle: in particular, under DOSish systems it is definitely a good
-idea to push :raw before you start.
+This module is deprecated in favour of PerlIO::eol, c.f.. The current
+version just pushes C<:eol(LF-CRLF)>. This means that C<:nline> won't
+show up in the output of C<PerlIO::get_layers> any more.
 
-Note that if this layer is pushed underneath (i.e. before) a layer such 
-as, say, :encoding(utf16) which produces binary data, the output will be
-nonsense.
+=head1 THANKS TO
+
+Audrey Tang, for taking my half-baked idea and turning it into something
+useful :).
 
 =head1 SEE ALSO
 
-L<PerlIO::crlf|:crlf>, L<PerlIO|PerlIO>.
+L<PerlIO::eol>.
 
 =head1 AUTHOR
 
@@ -41,7 +42,7 @@ Ben Morrow, E<lt>PerlIO-nline@morrow.me.ukE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2003 by Ben Morrow
+Copyright (C) 2006 by Ben Morrow
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.2 or,
